/**
 * Date工具模块
 * @date 2022-03
 * @author 何华东
 */
/**
 * 日期格式化字符串 => YYYY-MM-DD
 */
export declare let DATE_FORMAT: string;
/**
 * 日期+时间格式化字符串 => YYYY-MM-DD HH:mm:ss
 */
export declare let DATE_TIME_FORMAT: string;
export default class DateUtils {
    /**
     * 时间格式化
     * @param date 需要格式化的时间
     * @param format 时间格式字符串，默认为：'YYYY-MM-DD HH:mm:ss'
     * @returns
     */
    static format(date: any, format?: string): string;
    /**
     * 获取unix时间戳
     * @param date
     * @returns
     */
    static getUnixTimestamp(date?: any): any;
    /**
     * 求两个时间相差年份数
     * @param dateFrom 开始时间
     * @param dateTo 结束时间
     */
    static diffYears(dateFrom: any, dateTo: any): any;
    /**
     * 求两个时间相差月份数
     * @param dateFrom 开始时间
     * @param dateTo 结束时间
     */
    static diffMonths(dateFrom: any, dateTo: any): any;
    /**
     * 求两个时间相差天数
     * @param dateFrom 开始时间
     * @param dateTo 结束时间
     */
    static diffDays(dateFrom: any, dateTo: any): any;
    /**
     * 求两个时间相差分钟数
     * @param dateFrom 开始时间
     * @param dateTo 结束时间
     */
    static diffMinutes(dateFrom: any, dateTo: any): any;
    /**
     * 求两个时间相差秒数
     * @param dateFrom 开始时间
     * @param dateTo 结束时间
     */
    static diffSeconds(dateFrom: any, dateTo: any): any;
    /**
     * 求两个时间相差毫秒数
     * @param dateFrom 开始时间
     * @param dateTo 结束时间
     */
    static diffMilliseconds(dateFrom: any, dateTo: any): any;
    /**
     * 对Date的时间部分清零
     * @param date 需要清理的时间
     * @returns
     */
    static clearTime(date: Date): Date;
    /**
     * 验证时间是否为有效的时间格式
     */
    static isValid(date: any): any;
    /**
     * 获取前一个日期的时间,保留时间部分
     */
    static getPrevDate(date?: any): any;
    /**
     * 获取下一个日期的时间,保留时间部分
     */
    static getNextDate(date?: any): any;
    /**
     * 获取当月第一天的时间,保留时间部分
     */
    static getFirstDayOfMonth(date?: any): any;
    /**
     * 获取当月最后一天的时间,保留时间部分
     */
    static getLastDayOfMonth(date?: any): any;
    /**
     * 按天分割时间
     *
     * 例如：
        
        2022-5-1 13:23:22~2022-5-31 13:23:22 分割天数为7天

        2022-05-01 13:23:22 ~ 2022-05-07 23:59:59

        2022-05-08 00:00:00 ~ 2022-05-14 23:59:59

        2022-05-15 00:00:00 ~ 2022-05-21 23:59:59

        2022-05-22 00:00:00 ~ 2022-05-28 23:59:59

        2022-05-29 00:00:00 ~ 2022-05-31 13:23:22
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @param days 分割天数
     */
    static splitDateByDay(dateFrom: any, dateTo: any, days?: number): {
        dateFrom: Date;
        dateTo: Date;
    }[];
}
export { DateUtils };
